.. -*- mode: rst -*-
.. url = /about/
.. title = About
.. template_name = flatpages/rst.html
.. enable_comments = False
.. remove_comments = True

=======
 About
=======

This is an about page rendered from ReST_.

A Sub-Heading
=============

1. Item 1
2. Item 2

.. _ReST: http://docutils.sourceforge.net/
